@@ -1,5 +1,4 @@
 #!/bin/bash
-MODE=${1:-double}
 
 cnfpath=`realpath ../conf/node_mgr.cnf`
 source ./extra.env
@@ -11,11 +10,7 @@ num=`ps -ef | grep ${cnfpath} | grep -v grep | grep -v vim | wc -l`
 }
 
 if test "$USE_VALGRIND" = ""; then
-	if [ ${MODE} == "single" ]; then
-		./node_mgr ${cnfpath} ${MODE} >../log/std.log 2>&1 &
-	else
-		./node_mgr ${cnfpath} >../log/std.log 2>&1
-	fi
+	./node_mgr ${cnfpath} >../log/std.log 2>&1
 else
 	valgrind --leak-check=full --undef-value-errors=no ./node_mgr ${cnfpath} >../log/std.log 2>&1
 fi
